@@ -11,17 +11,17 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.044'; # VERSION
 
 #-----------------------------------------------------------------------------
 
 1;
 
-__END__
+
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -29,7 +29,7 @@ App::Pinto::Command::clean - remove orphaned distribution archives
 
 =head1 VERSION
 
-version 0.065_04
+version 0.044
 
 =head1 SYNOPSIS
 
@@ -40,16 +40,12 @@ version 0.065_04
 The database for L<Pinto> is transactional, so failures and aborted
 commands do not change the indexes.  However, the filesystem where
 distribution archives are physically stored is not transactional and
-may become cluttered with archives that are not in the database.
+may become cluttered with archives that are not on any stack.
 
 Normally, L<Pinto> tries to clean up those orphaned archives.  But in
 some cases it might not.  Running this command will force their
 removal.
 
-This command also runs some optimizations on the database.  So if
-your repository seems to be running slowly, try running this command
-to see if performance improves.
-
 =head1 COMMAND ARGUMENTS
 
 None.
@@ -60,7 +56,7 @@ None.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -70,3 +66,7 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
